@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.caching.interfaces import IRAMCached
 from plone.app.caching.operations.utils import storeResponseInRAMCache
 from plone.transformchain.interfaces import ITransform
@@ -7,12 +6,12 @@ from zope.interface import implementer
 from zope.interface import Interface
 
 
-GLOBAL_KEY = 'plone.app.caching.operations.ramcache'
+GLOBAL_KEY = "plone.app.caching.operations.ramcache"
 
 
 @implementer(ITransform)
 @adapter(Interface, Interface)
-class Store(object):
+class Store:
     """Transform chain element which actually saves the page in RAM.
 
     This is registered for the ``IRAMCached`` request marker, which is set by
@@ -28,25 +27,20 @@ class Store(object):
 
     def transformUnicode(self, result, encoding):
         if self.responseIsSuccess() and IRAMCached.providedBy(self.request):
-            storeResponseInRAMCache(self.request, self.request.response,
-                                    result.encode(encoding))
-        return None
+            storeResponseInRAMCache(
+                self.request, self.request.response, result.encode(encoding)
+            )
 
     def transformBytes(self, result, encoding):
         if self.responseIsSuccess() and IRAMCached.providedBy(self.request):
-            storeResponseInRAMCache(self.request, self.request.response,
-                                    result)
-        return None
+            storeResponseInRAMCache(self.request, self.request.response, result)
 
     def transformIterable(self, result, encoding):
         if self.responseIsSuccess() and IRAMCached.providedBy(self.request):
-            result = ''.join(result)
-            storeResponseInRAMCache(self.request, self.request.response,
-                                    result)
-            # as we have iterated the iterable, we must return a new one
-            return iter(result)
-        return None
+            result = b"".join(result)
+            storeResponseInRAMCache(self.request, self.request.response, result)
+            # ITransform contract allows to return an "encoded string" aka bytes
+            return result
 
     def responseIsSuccess(self):
-        status = self.request.response.getStatus()
-        return status == 200
+        return self.request.response.getStatus() == 200
